@@ -9,4 +9,6 @@ CITY_DB_PATH = path.join(DATA_DIR, 'GeoLiteCity.dat')
 ORG_DB_PATH = path.join(DATA_DIR, 'GeoIPOrg.dat')
 ASNUM_DB_PATH = path.join(DATA_DIR, 'GeoIPASNum.dat')
 ISP_DB_PATH = path.join(DATA_DIR, 'GeoIPISP.dat')
+NETSPEED_DB_PATH = path.join(DATA_DIR, 'GeoIPNetSpeed.dat')
+NETSPEEDCELL_DB_PATH = path.join(DATA_DIR, 'GeoIPNetSpeedCell.dat')
 CORRUPT_DB_PATH = path.join(DATA_DIR, '../config.py')
